@@ -898,9 +898,9 @@ def do_translate(config_flag=False):
 
     global YTDL_UPDATE_DICT
 
-    global MAIN_STAGE_QUEUED, MAIN_STAGE_ACTIVE, MAIN_STAGE_PAUSED, \
-    MAIN_STAGE_COMPLETED, MAIN_STAGE_ERROR, MAIN_STAGET_STALLED, \
-    ACTIVE_STAGE_PRE_PROCESS, ACTIVE_STAGE_DOWNLOAD, \
+    global MAIN_STAGE_QUEUED, MAIN_STAGE_NOT_STARTED, MAIN_STAGE_ACTIVE, \
+    MAIN_STAGE_PAUSED, MAIN_STAGE_COMPLETED, MAIN_STAGE_ERROR, \
+    MAIN_STAGE_STALLED, ACTIVE_STAGE_PRE_PROCESS, ACTIVE_STAGE_DOWNLOAD, \
     ACTIVE_STAGE_CONCATENATE, ACTIVE_STAGE_POST_PROCESS, \
     ACTIVE_STAGE_CAPTURE, ACTIVE_STAGE_MERGE, ACTIVE_STAGE_CHECKING, \
     COMPLETED_STAGE_FINISHED, COMPLETED_STAGE_WARNING, \
@@ -964,6 +964,7 @@ def do_translate(config_flag=False):
 
     #  Download operation stages
     MAIN_STAGE_QUEUED = _('Queued')
+    MAIN_STAGE_NOT_STARTED = _('Not started')
     MAIN_STAGE_ACTIVE = _('Active')
     MAIN_STAGE_PAUSED = _('Paused')                     # (not actually used)
     MAIN_STAGE_COMPLETED = _('Completed')               # (not actually used)
