@@ -1296,9 +1296,9 @@ class OptionsParser(object):
             options_manager_obj (options.OptionsManager): The object containing
                 the download options for this media data object
 
-            operation_type (str): 'sim', 'real', 'custom', 'classic_sim',
-                'classic_real', 'classic_custom' (matching possible values of
-                downloads.DownloadManager.operation_type)
+            operation_type (str): 'sim', 'real', 'custom_sim', 'custom_real',
+                'classic_sim', 'classic_real', 'classic_custom' (matching
+                possible values of downloads.DownloadManager.operation_type)
 
             scheduled_obj (media.Scheduled): If a scheduled download is
                 involved, the corresponding object (so bandwidth limits can be
@@ -1589,9 +1589,9 @@ class OptionsParser(object):
 
             copy_dict (dict): Copy of the original options dictionary
 
-            operation_type (str): 'sim', 'real', 'custom', 'classic_sim',
-                'classic_real', 'classic_custom' (matching possible values of
-                downloads.DownloadManager.operation_type)
+            operation_type (str): 'sim', 'real', 'custom_sim', 'custom_real',
+                'classic_sim', 'classic_real', 'classic_custom' (matching
+                possible values of downloads.DownloadManager.operation_type)
 
             options_list (list): List of download options compiled so far; this
                 function adds options directly to the list
@@ -1636,11 +1636,9 @@ class OptionsParser(object):
         #   'output_template' are ignored. However, 'output_format_list' is
         #   normally only used with yt-dlp)
         if not copy_dict['output_format_list'] \
-        and (
-            self.app_obj.ytdl_fork is None \
-            or self.app_obj.ytdl_fork != 'yt-dlp' \
-            or not self.app_obj.ytdlp_filter_options_flag
-        ):
+        or self.app_obj.ytdl_fork is None \
+        or self.app_obj.ytdl_fork != 'yt-dlp' \
+        or not self.app_obj.ytdlp_filter_options_flag:
             # Set the youtube-dl output template for the video's file
             template \
             = formats.FILE_OUTPUT_CONVERT_DICT[copy_dict['output_format']]
@@ -1689,7 +1687,8 @@ class OptionsParser(object):
 
             copy_dict (dict): Copy of the original options dictionary
 
-            operation_type (str): 'sim', 'real', 'custom', 'classic' (matching
+            operation_type (str): 'sim', 'real', 'custom_sim', 'custom_real',
+                'classic_sim', 'classic_real', 'classic_custom' (matching
                 possible values of downloads.DownloadManager.operation_type)
 
         """
